@@ -6,7 +6,7 @@ from ..models.mapfolder import MapFolder
 
 def upgrade(migrator: SchemaMigrator):
 	try:
-		query = RawQuery(MapFolder, """SELECT * FROM `mapfolder` WHERE public = 1""")
+		query = RawQuery(MapFolder, """SELECT * FROM mapfolder WHERE public = True""")
 		public_folders = query.execute()
 
 		migrate(
@@ -21,7 +21,7 @@ def upgrade(migrator: SchemaMigrator):
 
 def downgrade(migrator: SchemaMigrator):
 	try:
-		query = RawQuery(MapFolder, """SELECT * FROM `mapfolder` WHERE visibility = 'public'""")
+		query = RawQuery(MapFolder, """SELECT * FROM mapfolder WHERE visibility = 'public'""")
 		public_folders = query.execute()
 
 		migrate(
